@@ -8,7 +8,7 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include <KCModule>
 
 #ifdef WITH_KUSERFEEDBACK
@@ -19,7 +19,11 @@ class FeedbackConfigWidget;
 class KOPrefsUserFeedBack : public KCModule
 {
 public:
-    explicit KOPrefsUserFeedBack(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+    explicit KOPrefsUserFeedBack(QWidget *parent, const QVariantList &args = {});
+#else
+    explicit KOPrefsUserFeedBack(QObject *parent, const KPluginMetaData &data, const QVariantList &args = {});
+#endif
 
 protected:
     void load() override;
